@@ -18,7 +18,7 @@
 #
 # author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 
-from PyQt5 import QtGui, QtWidgets, QtCore
+from PyQt6 import QtGui, QtWidgets, QtCore
 import sys
 import os
 
@@ -60,7 +60,7 @@ class qweborfForm (QtWidgets.QWidget):
         self.ui.chkNAT.setEnabled(nhelper.can_redirect())
 
         self.defaultdir = QtCore.QStandardPaths.writableLocation(
-            QtCore.QStandardPaths.HomeLocation)
+            QtCore.QStandardPaths.StandardLocation.HomeLocation)
 
         initialdir = self.settings.value('main/defaultdir', self.defaultdir)
 
@@ -93,9 +93,9 @@ class qweborfForm (QtWidgets.QWidget):
             data = '<font color="red"><strong>ERROR</strong></font>: %s' % data
         elif level == self.DBG_NOTICE:
             data = '<font color="green"><strong>NOTICE</strong></font>: %s' % data
-        self.ui.txtLog.moveCursor(QtGui.QTextCursor.End)
+        self.ui.txtLog.moveCursor(QtGui.QTextCursor.MoveOperation.End)
         self.ui.txtLog.insertHtml(data + '<br>')
-        self.ui.txtLog.moveCursor(QtGui.QTextCursor.End)
+        self.ui.txtLog.moveCursor(QtGui.QTextCursor.MoveOperation.End)
 
     def setDefaultValues(self):
         '''Sets default values into the form GUI. It has to be
@@ -126,7 +126,7 @@ class qweborfForm (QtWidgets.QWidget):
 
     def about(self):
 
-        self.logger('<hr><strong>Qweborf 1.3</strong>')
+        self.logger('<hr><strong>Qweborf 1.4</strong>')
         self.logger('This program comes with ABSOLUTELY NO WARRANTY.'
                     ' This is free software, and you are welcome to redistribute it under certain conditions.'
                     ' For details see the <a href="http://www.gnu.org/licenses/gpl.html">GPLv3 Licese</a>.')
@@ -229,7 +229,7 @@ class qweborfForm (QtWidgets.QWidget):
             self,
             'Directory to share',
             current,
-            QtWidgets.QFileDialog.ShowDirsOnly
+            QtWidgets.QFileDialog.Option.ShowDirsOnly
         )
         if len(dirname) > 0:
             self.ui.txtPath.setText(dirname)
@@ -246,7 +246,7 @@ def q_main() -> None:
     ui.setupUi(Form)
     Form.setUi(ui)
     Form.show()
-    res = app.exec_()
+    res = app.exec()
     Form.terminate()
     sys.exit(res)
 
